@@ -2,13 +2,11 @@ from aiohttp import web
 from bson.json_util import dumps, JSONOptions
 
 json_options = JSONOptions(
-    tz_aware=False,
+    tz_aware=True,
     # tzinfo=get_tzinfo()
 )
 
 
-
-
 class WebResponse:
 
     @staticmethod
